@@ -292,9 +292,9 @@ class DescribeAbnormalEventRequest(AbstractModel):
         """
         :param SdkAppId: 用户SDKAppID，查询SDKAppID下任意20条异常体验事件（可能不同房间）
         :type SdkAppId: str
-        :param StartTime: 查询开始时间
+        :param StartTime: 查询开始时间,本地unix时间戳（1588031999s）
         :type StartTime: int
-        :param EndTime: 查询结束时间
+        :param EndTime: 查询结束时间,本地unix时间戳（1588031999s）
         :type EndTime: int
         :param RoomId: 房间号，查询房间内任意20条以内异常体验事件
         :type RoomId: str
@@ -358,7 +358,7 @@ class DescribeCallDetailRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s），查询实时数据时，查询起止时间不超过1个小时。
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -502,7 +502,7 @@ class DescribeDetailEventResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Data: 返回的事件列表
+        :param Data: 返回的事件列表，若没有数据，会返回空数组。
         :type Data: list of EventList
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
